package handler

import (
	"errors"
	"fusenapi/utils/auth"
	"net/http"

	"github.com/zeromicro/go-zero/core/logx"
	"github.com/zeromicro/go-zero/rest/httpx"

	"fusenapi/product/internal/logic"
	"fusenapi/product/internal/svc"
	"fusenapi/product/internal/types"
)

func GetProductInfoHandler(svcCtx *svc.ServiceContext) http.HandlerFunc {
	return func(w http.ResponseWriter, r *http.Request) {
		//用户登录信息
		userInfo := auth.CheckAuth(r)
		var req types.GetProductInfoReq
		if err := httpx.Parse(r, &req); err != nil {
			httpx.OkJsonCtx(r.Context(), w, &types.Response{
				Code:    510,
				Message: "parameter error",
			})
			logx.Info(err)
			return
		}
		l := logic.NewGetProductInfoLogic(r.Context(), svcCtx)
		resp := l.GetProductInfo(&req, userInfo)
		if resp != nil {
			httpx.OkJsonCtx(r.Context(), w, resp)
		} else {
			err := errors.New("server logic is error, resp must not be nil")
			httpx.ErrorCtx(r.Context(), w, err)
			logx.Error(err)
		}
	}
}
